BasicCPUMemory

Struct BasicCPUMemory 

pub struct BasicCPUMemory { /* private fields */ }
Memory is one contiguous 64KB buffer with no mapping or mirroring.

Implementations

Source

impl BasicCPUMemory

pub fn from_file(path: &String, offset: u16) -> Result<Self, Error>

For creating a memory buffer from a file. Specify an offset if you would like your data to be loaded in from a specific start point; if you set this to 0, it will begin loading data at 0x0.